@@ -31,16 +31,24 @@ This private submodule is *not* intended for importation by downstream callers.
 #as the inspect.signature() function is *GUARANTEED* to be a performance
 #bottleneck for us. This is low-priority for the moment and may actually never
 #happen... but it really should.
+#FIXME: Bwaha! We actually did this and even more space- and time-efficiently
+#than the above scheme. See the new
+#beartype.util.func.utilfuncargs.iter_func_args() generator, called like so:
+#    for arg_name, arg_kind, _ in iter_func_args(func): ...
+#*AWESOME.* Note we simply ignore the third item of each 3-tuple yielded by
+#that generator, as we currently have *NO* need for default values. We will
+#elsewhere certainly, but not quite yet. *shrug*
 
 # ....................{ IMPORTS                           }....................
 import inspect
-from beartype.cave import CallableCodeObjectType
-from beartype.roar import BeartypeDecorWrappeeException
-from beartype._util.func.utilfunccodeobj import get_func_codeobj
-from beartype._util.text.utiltextlabel import label_callable_decorated
+from beartype._decor._code.codesnip import (
+    ARG_NAME_FUNC,
+    ARG_NAME_RAISE_EXCEPTION,
+)
+from beartype._decor._error.errormain import raise_pep_call_exception
+from beartype._util.func.utilfuncscope import CallableScope
 from collections.abc import Callable
 from inspect import Signature
-from typing import Optional
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -65,39 +73,44 @@ class BeartypeData(object):
 
     Caveats
     ----------
-    **This object should not be used to communicate state between low-level
+    **This object cannot be used to communicate state between low-level
     memoized callables** (e.g.,
     :func:`beartype._decor._code._pep._pephint.pep_code_check_hint`) **and
     higher-level callables** (e.g.,
     :func:`beartype._decor._code.codemain.generate_code`). Instead, memoized
     callables *must* return that state as additional return values up the call
-    stack to those higher-level callables. Why? Because, by definition,
-    memoized callables are *not* recalled on subsequent calls passed the same
-    parameters. Since only the first call to those callables passed those
-    parameters will set the appropriate state on this object intended to be
-    communicated to higher-level callables, *all* subsequent calls will subtly
-    fail with difficult-to-diagnose issues. See also `<issue #5_>`__, which
-    exhibited this very complaint.
+    stack to those higher-level callables. By definition, memoized callables
+    are *not* recalled on subsequent calls passed the same parameters. Since
+    only the first call to those callables passed those parameters would set
+    the appropriate state on this object intended to be communicated to
+    higher-level callables, *all* subsequent calls would subtly fail with
+    difficult-to-diagnose issues. See also `<issue #5_>`__, which exhibited
+    this very complaint.
 
     .. _issue #5:
        https://github.com/beartype/beartype/issues/5
 
     Attributes
     ----------
-    func : Callable
+    func : Optional[Callable]
         **Decorated callable** (i.e., callable currently being decorated by the
-        :func:`beartype.beartype` decorator).
-    func_codeobj = CallableCodeObjectType
+        :func:`beartype.beartype` decorator) if the :meth:`reinit` method has
+        been called *or* ``None`` otherwise.
+    func_codeobj : Optional[CallableCodeObjectType]
         **Code object** (i.e., instance of the :class:`CodeType` type)
-        underlying the decorated callable.
-    func_sig : inspect.Signature
-        :class:`inspect.Signature` object describing this signature.
-
-    Attributes (String)
-    ----------
-    func_wrapper_name : str
+        underlying the decorated callable if the :meth:`reinit` method has been
+        called *or* ``None`` otherwise.
+    func_sig : Optional[inspect.Signature]
+        :class:`inspect.Signature` object describing this signature if the
+        :meth:`reinit` method has been called *or* ``None`` otherwise.
+    func_wrapper_locals : CallableScope
+        **Local scope** (i.e., dictionary mapping from the name to value of
+        each attribute referenced in the signature) of this wrapper function
+        required by this code snippet.
+    func_wrapper_name : Optional[str]
         Machine-readable name of the wrapper function to be generated and
-        returned by this decorator. To efficiently (albeit imperfectly) avoid
+        returned by this decorator if the :meth:`reinit` method has been called
+        *or* ``None`` otherwise. To efficiently (albeit imperfectly) avoid
         clashes with existing attributes of the module defining that function,
         this name is obfuscated while still preserving human-readability.
 
@@ -112,8 +125,10 @@ class BeartypeData(object):
     # write costs by approximately ~10%, which is non-trivial.
     __slots__ = (
         'func',
-        'func_codeobj',
+        #FIXME: Uncomment if needed.
+        # 'func_codeobj',
         'func_sig',
+        'func_wrapper_locals',
         'func_wrapper_name',
     )
 
@@ -149,8 +164,10 @@ class BeartypeData(object):
 
         # Nullify all remaining instance variables.
         self.func: Callable = None  # type: ignore[assignment]
-        self.func_codeobj: CallableCodeObjectType = None  # type: ignore[assignment]
+        #FIXME: Uncomment if needed.
+        # self.func_codeobj: CallableCodeObjectType = None  # type: ignore[assignment]
         self.func_sig: Signature = None  # type: ignore[assignment]
+        self.func_wrapper_locals: CallableScope = {}
         self.func_wrapper_name: str = None  # type: ignore[assignment]
 
 
@@ -187,40 +204,35 @@ class BeartypeData(object):
         assert callable(func), f'{repr(func)} uncallable.'
 
         # Avoid circular import dependencies.
-        from beartype._decor._pep563 import resolve_hints_postponed_if_needed
+        from beartype._decor._pep563 import resolve_hints_pep563_if_active
 
         # Callable currently being decorated.
         self.func = func
 
-        # Code object underlying this callable if this callable is a
-        # pure-Python function or method *OR* raise an exception otherwise.
-        self.func_codeobj = get_func_codeobj(
-            func=func, exception_cls=BeartypeDecorWrappeeException)
+        #FIXME: Uncomment if needed.
+        # Code object underlying that callable unwrapped if that callable is
+        # pure-Python *OR* raise an exception otherwise.
+        # self.func_codeobj = get_func_unwrapped_codeobj(
+        #     func=func, exception_cls=BeartypeDecorWrappeeException)
+
+        # Efficiently Reduce this local scope back to the dictionary of all
+        # parameters unconditionally required by *ALL* wrapper functions.
+        self.func_wrapper_locals.clear()
+        self.func_wrapper_locals[ARG_NAME_FUNC] = func
+        self.func_wrapper_locals[ARG_NAME_RAISE_EXCEPTION] = (
+            raise_pep_call_exception)
 
         # Machine-readable name of the wrapper function to be generated.
         self.func_wrapper_name = f'__beartyped_{func.__name__}'
 
         # Nullify all remaining attributes for safety *BEFORE* passing this
-        # object to any functions (e.g., resolve_hints_postponed_if_needed()).
+        # object to any functions (e.g., resolve_hints_pep563_if_active()).
         self.func_sig = None  # type: ignore[assignment]
 
-        # Resolve all postponed annotations if any on this callable *BEFORE*
-        # parsing the actual annotations these postponed annotations refer to.
-        resolve_hints_postponed_if_needed(self)
+        # Resolve all postponed hints on this callable if any *BEFORE* parsing
+        # the actual hints these postponed hints refer to.
+        resolve_hints_pep563_if_active(self)
 
         # "Signature" instance encapsulating this callable's signature,
         # dynamically parsed by the stdlib "inspect" module from this callable.
         self.func_sig = inspect.signature(func)
-
-    # ..................{ PROPERTIES ~ read-only            }..................
-    @property
-    def func_name(self) -> str:
-        '''
-        Human-readable name of this callable.
-
-        This attribute is only accessed when raising exceptions (where
-        efficiency is entirely ignorable) and thus intentionally declared as a
-        read-only property rather than an instance variable.
-        '''
-
-        return label_callable_decorated(self.func)
