@@ -137,139 +137,21 @@ This private submodule is *not* intended for importation by downstream callers.
 #  "_PARAM_KIND_IGNORABLE" set.
 #* Remove the "_PARAM_KIND_IGNORABLE" set entirely.
 
-#FIXME: [NEW PROJECT] Consider creating a new "beartype/bearclaw" project *OR
-#SOMETHING* (e.g., "bearcall", "bearely", etc.) to enable arbitrary O(1)
-#runtime type checking. Actually, "bearely" is a super-hot name, so let's run
-#with that, shall we? By "arbitrary," we mean just that: O(1) runtime type
-#checking that anyone can perform in any arbitrary expression without having to
-#isolate that checking to a callable signature.
-#
-#First, let's spec the public API. Fortunately, that's trivial. Just as with
-#"beartype", we define only a single public turbo-charged function:
-#* Define a public "bearely" package.
-#* Define a private "bearely._main" submodule *OR SOMETHING.*
-#* In that submodule:
-#  * Define a public istypedas() tester with the signature:
-#
-#    def istypedas(obj: object, hint: object) -> bool:
-#
-#    ...where "obj" is any arbitrary object and "hint" is any PEP-compliant
-#    type hint (or, more generally, any @beartype-compliant type hint).
-#  * Actually, define a public is_typed_as() alias to the istypedas() tester.
-#    Not everyone wants cute names; PEP 8-compliant snake case is often
-#    preferable and we ourselves would probably prefer the former, for example.
-#* Define a dunder "bearely.__init__" submodule publicizing
-#  bearely._main.istypedas() as "bearely.istypedas().
-#* Have "bearely" depend upon "beartype" as its only mandatory runtime
-#  dependency.
-#
-#*YUP.* istypedas() is the single public turbo-charged function declared by
-#this package. The nomenclature for this tester derives, of course, from the
-#builtin isinstanceof() and issubclassof() builtins. istypedas() could be
-#considered a generalization or proper superset of both -- in that anything you
-#can do with those builtins you can do with istypedas(), but you can also do
-#*MUCH* more with istypedas().
-#
-#Fortuitously, implementing istypedas() in terms of the existing @beartype
-#decorator is trivial and requires absolutely *NO* refactoring of the
-#"beartype" codebase itself, which is certainly nice (albeit non-essential):
-#* Internally, istypedas() should maintain a *non-LRU* cache (probably in a
-#  separate "bearely._cache" submodule as a simple dictionary) named
-#  "HINT_OR_HINT_REPR_TO_BEARTYPE_WRAPPER" mapping from each arbitrary
-#  PEP-compliant type hint (passed as the second parameter to istypedas()) to
-#  the corresponding wrapper function dynamically generated by the @beartype
-#  decorator checking an arbitrary object against that hint. However, note
-#  there there's a significant caveat here:
-#  * *NOT ALL HINTS ARE CACHABLE.* If the passed hint is *NOT* cachable, we
-#    should instead cache that hint under its machine-readable repr() string.
-#    While slower to generate, generating that string is still guaranteed to be
-#    *MUCH* faster than dynamically declaring a new function each call.
-#* The trivial way to implement the prior item is to dynamically define one new
-#  private @beartype-decorated noop function accepting an arbitrary parameter
-#  type-hinted by each type hint: e.g.,
-#      # Pseudo-code, obviously. Again, this snippet should probably be
-#      # shifted into a new "bearely._snip" submodule.
-#      is_typed_as_wrapper = exec(f'''
-#      @beartype
-#      def is_typed_as_wrapper(obj: {hint}): pass
-#      ''')
-#* After either defining and caching that wrapper into the above dictionary
-#  *OR* retrieved a previously wrapper from that dictionary, trivially
-#  implement this check with EAFP as follows:
-#      try:
-#          is_typed_as_wrapper(obj)
-#          return True
-#      except:
-#          return False
-#
-#*DONE.* Sweet, yah? The above can and should be heavily optimized, of course.
-#How? That remains to be determined. The principle issue with the above
-#approach is that it unnecessarily incurs an additional stack frame. Since the
-#original is_typed_as_wrapper() function wrapped by @beartype doesn't actually
-#do anything, it would be really nice if the wrapper generated by @beartype
-#omitted the call to that original function.
-#
-#This might be easier than expected. You're probably thinking AST inspector or
-#disassembly, right? Neither of those two things are easy or fast, so let's do
-#neither. Is there any alternative? There might be. In theory, the code object
-#for any callable whose implementation is literally "pass" should be trivially
-#detectable via metadata on that object. If nothing else, the byte code for
-#that object should be a constant size; any code object whose byte code is
-#larger than that size is *NOT* a "pass" noop.
-#
-#In any case, @beartype should efficiently detect noop callables and avoid
-#calling those callables from the wrapper functions it generates for those
-#callables. This would be genuinely useful from the general-purpose
-#perspective, which means we should make this happen.
-
 # ....................{ IMPORTS                           }....................
-import functools, random
 from beartype.roar import (
     BeartypeDecorWrappeeException,
     BeartypeDecorWrapperException,
 )
 from beartype._decor._code.codemain import generate_code
-from beartype._decor._code.codesnip import (
-    ARG_NAME_FUNC, ARG_NAME_TYPISTRY)
 from beartype._decor._data import BeartypeData
-from beartype._decor._cache.cachetype import bear_typistry
 from beartype._util.cache.pool.utilcachepoolobjecttyped import (
     acquire_object_typed, release_object_typed)
-from beartype._decor._code._pep._error.peperror import (
-    raise_pep_call_exception)
-from beartype._util.text.utiltextmunge import number_lines
+from beartype._util.func.utilfuncmake import make_func
 from typing import Callable, TYPE_CHECKING
-# from beartype._util.utilobject import get_object_name
-# from types import FunctionType
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
 
-# ....................{ CONSTANTS                         }....................
-_GLOBAL_ATTRS = {
-    '__beartype_getrandbits': random.getrandbits,
-    '__beartype_raise_pep_call_exception': raise_pep_call_exception,
-}
-'''
-Dictionary mapping from the name to value of all attributes internally
-accessed as globals (rather than as locals externally passed as private default
-parameters) in wrapping functions created and returned by the :func:`beartype`
-decorator.
-
-The names of these attributes are embedded in one or more string global
-constants declared by one or more snippet submodules (e.g.,
-:mod:`beartype._decor._code.codesnip`). To avoid colliding with the names of
-arbitrary caller-defined parameters, these names *must* be aliased under
-alternate names prefixed by ``__beartype_``.
-
-Caveats
-----------
-**Attributes frequently accessed in the body of these functions should instead
-be externally passed as default parameters into these functions.** This
-includes the frequently accessed ``__beartypistry`` local, which is thus passed
-as a private default parameter to the signatures of these functions.
-'''
-
 # ....................{ DECORATORS                        }....................
 def beartype(func: Callable) -> Callable:
     '''
@@ -335,6 +217,11 @@ def beartype(func: Callable) -> Callable:
         * Uncallable.
         * A class, which :mod:`beartype` currently fails to support.
         * A C-based callable (e.g., builtin, third-party C extension).
+    BeartypeDecorWrapperException
+        If this decorator erroneously generates a syntactically invalid wrapper
+        function. This should *never* happen, but here we are, so this probably
+        happened. Please submit an upstream issue with our issue tracker if you
+        ever see this. (Thanks and abstruse apologies!)
 
     .. _PEP 484:
        https://www.python.org/dev/peps/pep-0484
@@ -371,53 +258,18 @@ def beartype(func: Callable) -> Callable:
         # returning this callable as is.
         return func
 
-    #FIXME: Optimize by caching and reusing previously cached "BeartypeData"
-    #instances across @beartype decorations. To do so:
-    #
-    #* Define a new "beartype._util.cache.utilcachepoolobj" submodule copied
-    #  from the existing "beartype._util.cache.list.utilfixedlistpool"
-    #  submodule. "utilcachepoolobj" should publish a similar API, except:
-    #  * Keys should be arbitrary classes rather than integers.
-    #  * Pool items should be arbitrary objects of those classes rather than
-    #    fixed lists.
-    #* Define a new BeartypeData.init() method resembling the existing
-    #  BeartypeData.__init__() dunder method.
-    #* Call (in order):
-    #  func_data = utilcachepoolobj.acquire_object(BeartypeData)
-    #  func_data.init(func)
-
     # Previously cached callable metadata reinitialized from this callable.
     func_data = acquire_object_typed(BeartypeData)
     func_data.reinit(func)
 
     # Generate the raw string of Python statements implementing this wrapper.
-    func_code, is_func_code_noop = generate_code(func_data)
+    func_wrapper_code = generate_code(func_data)
 
-    # If this wrapper proxies this callable *WITHOUT* type-checking,
-    # efficiently reduce to a noop (i.e., the identity decorator) by returning
-    # this callable as is.
-    if is_func_code_noop:
+    # If this callable requires *NO* type-checking, silently reduce to a noop
+    # and thus the identity decorator by returning this callable as is.
+    if not func_wrapper_code:
         return func
 
-    # Dictionary mapping from local attribute names to values passed to the
-    # module-scoped outermost definition (but *NOT* the actual body) of this
-    # wrapper. Note that:
-    #
-    # * For efficiency, only attributes specific to the body of this wrapper
-    #   are copied from the current namespace. Attributes generically
-    #   applicable to the body of all wrappers are instead implicitly imported
-    #   from this submodule by passing "_GLOBAL_ATTRS" below.
-    # * For each attribute specified here, one new keyword parameter of the
-    #   form "{local_attr_key_name}={local_attr_key_name}" *MUST* be added to
-    #   the signature for this wrapper defined by the "CODE_SIGNATURE" string.
-    #
-    # For the above reasons, the *ONLY* attribute that should be passed is the
-    # wrapper-specific "__beartype_func" attribute.
-    local_attrs = {
-        ARG_NAME_FUNC: func,
-        ARG_NAME_TYPISTRY: bear_typistry,
-    }
-
     #FIXME: Uncomment after uncommenting the corresponding logic below.
     # Fully-qualified name of this undecorated callable to be decorated.
     # func_name_qualified = get_object_name(func)
@@ -489,76 +341,27 @@ def beartype(func: Callable) -> Callable:
     #Indeed, see the _make() function of the "makefun.main" submodule:
     #    https://github.com/smarie/python-makefun/blob/master/makefun/main.py
 
-    # Attempt to define this wrapper as a closure of this decorator. For
-    # obscure and presumably uninteresting reasons, Python fails to locally
-    # declare this closure when the locals() dictionary is passed; to capture
-    # this closure, a local dictionary must be passed instead.
+    # Function wrapping this callable with type-checking to be returned.
     #
-    # Note that the same result may also be achieved via the compile() builtin
-    # and "types.FunctionType" class: e.g.,
-    #
-    #     func_code_compiled = compile(
-    #         func_code, "<string>", "exec").co_consts[0]
-    #     return types.FunctionType(
-    #         code=func_code_compiled,
-    #         globals=_GLOBAL_ATTRS,
-    #         argdefs=('__beartype_func', func)
-    #     )
-    #
-    # Since doing so is both more verbose and obfuscatory for no tangible gain,
-    # the current circumspect approach is preferred.
-    try:
-        # print('\n@beartyped {} wrapper:\n\n{}\n'.format(func_data.func_name, func_code))
-        # print('\n@beartyped {} wrapper:\n\n{}\n'.format(func_data.func_name, number_lines(func_code)))
-        exec(func_code, _GLOBAL_ATTRS, local_attrs)
-
-        #FIXME: See above.
-        #FIXME: Should "exec" be "single" instead? Does it matter? Is there any
-        #performance gap between the two?
-        # func_code_compiled = compile(
-        #     func_code, func_wrapper_filename, "exec").co_consts[0]
-        # return FunctionType(
-        #     code=func_code_compiled,
-        #     globals=_GLOBAL_ATTRS,
-        #
-        #     #FIXME: This really doesn't seem right, but... *shrug*
-        #     argdefs=tuple(local_attrs.values()),
-        # )
-    # If doing so fails for any reason, raise an exception suffixed by
-    # debuggable wrapper code such that each line of this code is prefixed by
-    # that line's number, rendering "SyntaxError" exceptions referencing
-    # arbitrary line numbers human-readable: e.g.,
-    #       File "<string>", line 56
-    #         if not (
-    #          ^
-    #     SyntaxError: invalid syntax
-    except Exception as exception:
-        raise BeartypeDecorWrapperException(
-            f'@beartyped {func_data.func_name} wrapper unparseable:\n\n'
-            f'{number_lines(func_code)}'
-        ) from exception
-
-    # This wrapper.
-    #
-    # Note that, as the above logic successfully compiled this wrapper, this
-    # dictionary is guaranteed to contain a key with this wrapper's name whose
-    # value is this wrapper. Ergo, no additional validation of the existence of
-    # this key or type of this wrapper is needed.
-    func_wrapper: Callable = local_attrs[func_data.func_wrapper_name]  # type: ignore[assignment]
+    # For efficiency, this wrapper accesses *ONLY* local rather than global
+    # attributes. The latter incur a minor performance penalty, since local
+    # attributes take precedence over global attributes, implying all global
+    # attributes are *ALWAYS* first looked up as local attributes before
+    # falling back to being looked up as global attributes.
+    func_wrapper = make_func(
+        func_name=func_data.func_wrapper_name,
+        func_code=func_wrapper_code,
+        func_locals=func_data.func_wrapper_locals,
+        func_label=f'@beartyped {func.__name__}() wrapper',
+        func_wrapped=func,
+        exception_cls=BeartypeDecorWrapperException,
+    )
 
     # Declare this wrapper to be generated by @beartype, which tests for the
     # existence of this attribute above to avoid re-decorating callables
     # already decorated by @beartype by efficiently reducing to a noop.
     func_wrapper.__beartype_wrapper = True  # type: ignore[attr-defined]
 
-    # Propagate identifying metadata (stored as special attributes) from the
-    # original function to this wrapper for debuggability, including:
-    #
-    # * "__name__", the unqualified name of this function.
-    # * "__doc__", the docstring of this function (if any).
-    # * "__module__", the fully-qualified name of this function's module.
-    functools.update_wrapper(wrapper=func_wrapper, wrapped=func)
-
     # Release this callable metadata back to its object pool.
     release_object_typed(func_data)
 
