@@ -11,7 +11,6 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
-from beartype.cave import HintGenericSubscriptedType
 from beartype.roar import (
     BeartypeDecorHintPepException,
     BeartypeDecorHintPepDeprecatedWarning,
@@ -19,6 +18,7 @@ from beartype.roar import (
     # BeartypeDecorHintPepIgnorableDeepWarning,
     # BeartypeDecorHintPepUnsupportedWarning,
 )
+from beartype._cave._cavefast import HintGenericSubscriptedType
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.hint.data.pep.utilhintdatapep import (
     HINT_PEP_SIGNS_DEPRECATED,
@@ -46,7 +46,7 @@ from beartype._util.hint.pep.proposal.utilhintpep593 import (
 from beartype._util.py.utilpymodule import get_object_module_name
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
 from beartype._util.utilobject import get_object_type_unless_type
-from typing import TypeVar
+from typing import Type, TypeVar
 from warnings import warn
 
 # See the "beartype.cave" submodule for further commentary.
@@ -87,7 +87,7 @@ def die_if_hint_pep(
 
     # Optional parameters.
     hint_label: str = 'Type hint',
-    exception_cls: type = BeartypeDecorHintPepException,
+    exception_cls: Type[Exception] = BeartypeDecorHintPepException,
 ) -> None:
     '''
     Raise an exception if the passed object is a **PEP-compliant type
@@ -123,7 +123,7 @@ def die_if_hint_pep(
 
         # Raise an exception of this class.
         raise exception_cls(
-            f'{hint_label} {repr(hint)} PEP type hint '
+            f'{hint_label} {repr(hint)} is PEP type hint '
             f'(e.g., rather than non-"typing" type).'
         )
 
@@ -241,9 +241,7 @@ def die_if_hint_pep_unsupported(
     # Regardless of whether it is or isn't, we raise a similar exception. Ergo,
     # there's no benefit to validating that expectation here.
     raise BeartypeDecorHintPepUnsupportedException(
-        f'{hint_label} PEP type hint "{repr(hint)}" '
-        f'currently unsupported by @beartype.'
-    )
+        f'{hint_label} {repr(hint)} currently unsupported by @beartype.')
 
 
 def die_if_hint_pep_sign_unsupported(
@@ -284,8 +282,9 @@ def die_if_hint_pep_sign_unsupported(
     if not is_hint_pep_sign_supported(hint_sign):
         assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
         raise BeartypeDecorHintPepUnsupportedException(
-            f'{hint_label} PEP sign {repr(hint_sign)} '
-            f'currently unsupported by @beartype.')
+            f'{hint_label} sign {repr(hint_sign)} '
+            f'currently unsupported by @beartype.'
+        )
 
 # ....................{ WARNINGS                          }....................
 #FIXME: Resurrect support for the passed "hint_label" parameter. We've
