@@ -87,7 +87,7 @@ justification of this constant's current value.
 '''
 
 
-PYTHON_VERSION_MINOR_MAX = 9
+PYTHON_VERSION_MINOR_MAX = 10
 '''
 Maximum minor stable version of this major version of Python currently released
 (e.g., ``5`` if Python 3.5 is the most recent stable version of Python 3.x).
@@ -188,7 +188,7 @@ if _sys.version_info[:3] < PYTHON_VERSION_MIN_PARTS:
 # For further details, see http://semver.org.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-VERSION = '0.6.0'
+VERSION = '0.7.0'
 '''
 Human-readable package version as a ``.``-delimited string.
 '''
@@ -260,6 +260,12 @@ URL_ISSUES = f'{URL_HOMEPAGE}/issues'
 URL of this package's issue tracker.
 '''
 
+
+URL_RELEASES = f'{URL_HOMEPAGE}/issues'
+'''
+URL of this package's release list.
+'''
+
 # ....................{ METADATA ~ libs : runtime         }....................
 LIBS_RUNTIME_OPTIONAL = ()
 '''
@@ -306,8 +312,23 @@ https://mypy.readthedocs.io/en/stable/faq.html#does-it-run-on-pypy
 '''
 
 
+LIBS_TESTTIME_MANDATORY_COVERAGE = (
+    'coverage >=5.5',
+)
+'''
+**Mandatory test-time coverage package dependencies** (i.e., dependencies
+required to measure test coverage for this package) as a tuple of
+:mod:`setuptools`-specific requirements strings of the format ``{project_name}
+{comparison1}{version1},...,{comparisonN}{versionN}``.
+
+See Also
+----------
+:data:`LIBS_RUNTIME_OPTIONAL`
+    Further details.
+'''
+
+
 LIBS_TESTTIME_MANDATORY_TOX = _LIBS_TESTTIME_MANDATORY_MYPY + (
-    # A fairly modern version of pytest is required.
     'pytest >=4.0.0',
 )
 '''
@@ -338,6 +359,7 @@ See Also
 
 
 LIBS_TESTTIME_MANDATORY = (
+    LIBS_TESTTIME_MANDATORY_COVERAGE +
     LIBS_TESTTIME_MANDATORY_TOX +
     LIBS_TESTTIME_OPTIONAL + (
         # A relatively modern version of tox is required.
