@@ -30,13 +30,13 @@ Note that:
 
 # ....................{ IMPORTS                           }....................
 import contextlib, re
-from beartype.cave import (
+from beartype._cave._cavefast import (
     NoneType,
     RegexMatchType,
     RegexCompiledType,
 )
 from beartype._util.hint.data.pep.proposal.utilhintdatapep484 import (
-    HINT_PEP484_BASE_FORWARDREF)
+    HINT_PEP484_TYPE_FORWARDREF)
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_3_6,
     IS_PYTHON_AT_LEAST_3_7,
@@ -316,7 +316,7 @@ def add_data(data_module: 'ModuleType') -> None:
         TypeVar,
 
         # The "ForwardRef" class as is does *NOT* constitute a valid type hint.
-        HINT_PEP484_BASE_FORWARDREF,
+        HINT_PEP484_TYPE_FORWARDREF,
     ))
 
     # ..................{ TUPLES                            }..................
@@ -1669,6 +1669,7 @@ def add_data(data_module: 'ModuleType') -> None:
             PepHintMetadata(
                 hint=Hashable,
                 pep_sign=Hashable,
+                stdlib_type=collections_abc.Hashable,
                 piths_satisfied_meta=(
                     # String constant.
                     PepHintPithSatisfiedMetadata(
@@ -1686,13 +1687,13 @@ def add_data(data_module: 'ModuleType') -> None:
                         'Of language',
                     ]),
                 ),
-                stdlib_type=collections_abc.Hashable,
             ),
 
             # Unsubscripted "Sized" attribute.
             PepHintMetadata(
                 hint=Sized,
                 pep_sign=Sized,
+                stdlib_type=collections_abc.Sized,
                 piths_satisfied_meta=(
                     # String constant.
                     PepHintPithSatisfiedMetadata('Faire, a'),
@@ -1706,7 +1707,6 @@ def add_data(data_module: 'ModuleType') -> None:
                     # Boolean constant.
                     PepHintPithUnsatisfiedMetadata(False),
                 ),
-                stdlib_type=collections_abc.Sized,
             ),
         ))
 
